[![size_badge](https://img.shields.io/github/repo-size/andrey-git/pysensibo?style=for-the-badge&cacheSeconds=3600)](https://github.com/andrey-git/pysensibo)
[![version_badge](https://img.shields.io/github/v/release/andrey-git/pysensibo?label=Latest%20release&style=for-the-badge&cacheSeconds=3600)](https://github.com/andrey-git/pysensibo/releases/latest)
[![download_badge](https://img.shields.io/pypi/dm/pysensibo?style=for-the-badge&cacheSeconds=3600)](https://github.com/andrey-git/pysensibo/releases/latest)
![GitHub Repo stars](https://img.shields.io/github/stars/andrey-git/pysensibo?style=for-the-badge&cacheSeconds=3600)
![GitHub Issues or Pull Requests](https://img.shields.io/github/issues/andrey-git/pysensibo?style=for-the-badge&cacheSeconds=3600)
![GitHub License](https://img.shields.io/github/license/andrey-git/pysensibo?style=for-the-badge&cacheSeconds=3600)

[![Made for Home Assistant](https://img.shields.io/badge/Made_for-Home%20Assistant-blue?style=for-the-badge&logo=homeassistant)](https://github.com/home-assistant)

[![Sponsor me](https://img.shields.io/badge/Sponsor-Me-blue?style=for-the-badge&logo=github)](https://github.com/sponsors/gjohansson-ST)
[![Discord](https://img.shields.io/discord/872446427664625664?style=for-the-badge&label=Discord&cacheSeconds=3600)](https://discord.gg/EG7cWFQMGW)

# pysensibo
asyncio-friendly python API for Sensibo (https://sensibo.com). Supported on Python 3.11+

Package has been made specifically for [Home Assistant](https://www.home-assistant.io/)

For example usage see test-files
